function [lamda_opt,Delay,Fval] = opt_global_FIFO(L,lamda0,Nof_nodes,s,C)

    fprintf('FIFO global solution\n');
    fprintf('-----------------------\n');
    
    Delay=zeros(1,Nof_nodes);
    Fval=0;
    
    %----------------------The Constraints---------------------------------%

    lb=zeros(Nof_nodes^2,1);                                                % lamda(i,j)>=0
    
    Aeq=zeros(2*Nof_nodes,Nof_nodes^2);                                     % lamda(i,j)=L(i) for each i
    beq=[L';zeros(Nof_nodes,1)];
    
    Aineq=zeros(Nof_nodes,Nof_nodes^2);                                     % lamda(i,j)s(i)<C(j)    for each j
    bineq = 0.999*C;
    
    for i=1:Nof_nodes
        Aeq(i,(i-1)*Nof_nodes + (1:Nof_nodes))=1;
        Aeq(i+Nof_nodes,i+(i-1)*Nof_nodes)=1;
        Aineq(i,i:Nof_nodes:Nof_nodes^2)=s(1:Nof_nodes);                                         
    end

    %------------------------Optimization----------------------------------%

    lb
    Aeq
    beq
    Aineq
    bineq
    
    lamda_vec0=reshape(lamda0',[],1);                                       %the initial traffic splits vector

    options = optimset('Diagnostics','off','LargeScale','off','Display','iter','GradObj','off','DerivativeCheck','off'); 
    [X,Fval]=fmincon(@setobjfungrad,lamda_vec0,Aineq,bineq,Aeq,beq,lb,[],[],options);    
     
    lamda_opt=reshape(abs(X),Nof_nodes,[])';
    [Delay,Fval]= calc_delay_FIFO(L,lamda_opt,Nof_nodes,s,C);
    
    
    %------------------Objective function F -------------------------------%
    function F = setobjfungrad(lamda)
        
        lamda_cur=reshape(lamda,Nof_nodes,[])';

        F=0;
        D=zeros(Nof_nodes);
        Delay=zeros(1,Nof_nodes);
        W=zeros(1,Nof_nodes);
    
        for j=1:Nof_nodes
            numerator=(s.^2)*lamda_cur(:,j);
            denominator=C(j)*(C(j)-s*lamda_cur(:,j));
            W(j)=numerator/denominator;
        end


        for i=1:Nof_nodes
            for j=1:Nof_nodes

                if(i==j)
                    continue
                end

                D(i,j)= W(j) + s(i)/C(j);
                Delay(i)=Delay(i)+lamda_cur(i,j)*D(i,j)/L(i);
            end

            F=F+L(i)*Delay(i)/sum(L);
        end
        
    end

    
end
